@@ -1,3 +1,4 @@
+import sys
 from odoo_tools.compat import Path
 from ..configuration.git import checkout_repo
 from .misc import (
@@ -10,6 +11,7 @@ from six import ensure_binary, ensure_str
 import logging
 import requests
 from packaging.version import parse as version_parse
+from .pip import pip_command
 
 _logger = logging.getLogger(__name__)
 
@@ -119,29 +121,19 @@ class OdooSource(object):
             self.installed_release
         )
 
-        if hasattr(self.options, 'languages'):
-            languages = self.options.languages
-        else:
-            languages = 'all'
+        languages = self.options.languages
 
         self.strip_languages(languages)
 
         _logger.info("Installing odoo")
 
-        args = ['python', '-m', 'pip', 'install']
+        target = self.options.target
+        upgrade = self.options.upgrade
 
-        if hasattr(self.options, 'upgrade') and self.options.upgrade:
-            args.append('-U')
-
-        if hasattr(self.options, 'target') and self.options.target:
-            args += [
-                "--target", str(self.options.target),
-                "--implementation", "cp",
-                "--python", "3.8",
-                # "--only-binary", ":all:"
-                "--no-deps",
-            ]
+        args = pip_command(target=target, upgrade=upgrade)
 
+        # Ensure setuptools less than 58 is installed for odoo
+        # versions from 11 to 13.
         if (
             self.parsed_version.major > 10 and
             self.parsed_version.major < 14
@@ -278,45 +270,3 @@ class OfficialRelease(OdooSource):
 
     def install(self):
         super().install()
-#
-#
-#   def setup_odoo_from_git(repo, ref, version, options=None):
-#
-#       if hasattr(options, 'cache'):
-#           cache = options.cache
-#       else:
-#           cache = None
-#
-#       installer = GitRelease(
-#           version,
-#           repo,
-#           ref,
-#           options=options,
-#           cache=cache
-#       )
-#
-#       with installer:
-#           if installer.need_update():
-#               installer.fetch()
-#               installer.checkout()
-#               installer.install()
-#
-#
-#   def setup_odoo_release(version, release, options=None):
-#       if hasattr(options, 'cache'):
-#           cache = options.cache
-#       else:
-#           cache = None
-#
-#       installer = OfficialRelease(
-#           version,
-#           release,
-#           options=options,
-#           cache=cache
-#       )
-#
-#       with installer:
-#           if installer.need_update():
-#               installer.fetch()
-#               installer.checkout()
-#               installer.install()
